@@ -58,6 +58,7 @@ int g_log_level=0;
  * grep MARK /tmp/logfile.strace
  * grep MARK /tmp/logfile.strace|sed s/", F_OK) = -1 ENOENT (No such file or directory)"/\)/
  * */
+/*
 void program_log (const char *format, ...)
 {
         va_list args;
@@ -73,6 +74,7 @@ void program_log (const char *format, ...)
         access (str, F_OK);
         g_free (str);
 }
+*/
 
 /* Print message at various level:
  * < 0     = Debug (Use only in special debug code which should not be in 
@@ -87,6 +89,7 @@ void orage_message(gint level, const char *format, ...)
 {
     va_list args;
     char *formatted;
+    struct tm *t = orage_localtime();
 
     if (level < g_log_level)
         return;
@@ -94,7 +97,8 @@ void orage_message(gint level, const char *format, ...)
     formatted = g_strdup_vprintf(format, args);
     va_end(args);
 
-    if (level < 0) 
+    g_print("%02d:%02d:%02d ", t->tm_hour, t->tm_min, t->tm_sec);
+    if (level < 0)
         g_debug("%s", formatted);
     else if (level < 100) 
         g_message("Orage **: %s", formatted);
@@ -316,6 +320,53 @@ GtkWidget *orage_menu_item_new_with_mnemonic(const gchar *label
     return menu_item;
 }
 
+/* replace old with new string in text.
+   if changes are done, returns newly allocated char *, which needs to be freed
+   if there are no changes, it returns the original string without freeing it.
+   You can always use this like 
+   str=orage_replace_text(str, old, new);
+   but it may point to new place.
+*/
+char *orage_replace_text(char *text, char *old, char *new)
+{
+#undef P_N
+#define P_N "orage_replace_text: "
+    /* these point to the original string and travel it until no more commands 
+     * are found:
+     * cur points to the current head (after each old if any found)
+     * cmd points to the start of next old in text */
+    char *cur, *cmd;
+    char *beq=NULL; /* beq is the total new string. */
+    char *tmp;      /* temporary pointer to handle freeing */
+
+    for (cur = text; cur && (cmd = strstr(cur, old)); cur = cmd + strlen(old)) {
+        cmd[0] = '\0'; /* temporarily */
+        if (beq) { /* we already have done changes */
+            tmp = beq;
+            beq = g_strconcat(tmp, cur, new, NULL);
+            g_free(tmp);
+        }
+        else /* first round */
+            beq = g_strconcat(cur, new, NULL);
+        cmd[0] = old[0]; /* back to real value */
+    }
+
+    if (beq) {
+        /* we found and processed at least one command, 
+         * add the remaining fragment and return it */
+        tmp = beq;
+        beq = g_strconcat(tmp, cur, NULL);
+        g_free(tmp);
+        g_free(text); /* free original string as we changed it */
+    }
+    else {
+        /* we did not find any commands,
+         * so just return the original string */
+        beq = text;
+    }
+    return(beq);
+}
+
 /* this will change <&Xnnn> type commands to numbers or text as defined.
  * Currently the only command is 
  * <&Ynnnn> which calculates years between current year and nnnn */
@@ -422,6 +473,7 @@ GtkWidget *orage_period_hbox_new(gboolean head_space, gboolean tail_space
     gtk_box_pack_start(GTK_BOX(hbox), space_label, FALSE, FALSE, 0);
 
     gtk_spin_button_set_wrap(GTK_SPIN_BUTTON(spin_mm), TRUE);
+    gtk_spin_button_set_increments(GTK_SPIN_BUTTON(spin_mm), 5, 10);
     /* gtk_widget_set_size_request(spin_mm, 40, -1); */
     gtk_box_pack_start(GTK_BOX(hbox), spin_mm, FALSE, FALSE, 0);
 
@@ -480,7 +532,7 @@ struct tm orage_i18_time_to_tm_time(const char *i18_time)
     if (ret == NULL)
         g_error("Orage: orage_i18_time_to_tm_time wrong format (%s)", i18_time);
     else if (ret[0] != '\0')
-        g_error("Orage: orage_i18_time_to_tm_time too long format (%s-%s)"
+        g_warning("Orage: orage_i18_time_to_tm_time too long format (%s). Ignoring:%s)"
                 , i18_time, ret);
     return(tm_time);
 }
@@ -494,7 +546,7 @@ struct tm orage_i18_date_to_tm_date(const char *i18_date)
     if (ret == NULL)
         g_error("Orage: orage_i18_date_to_tm_date wrong format (%s)", i18_date);
     else if (ret[0] != '\0')
-        g_error("Orage: orage_i18_date_to_tm_date too long format (%s-%s)"
+        g_warning("Orage: orage_i18_date_to_tm_date too long format (%s). Ignoring:%s)"
                 , i18_date, ret);
     return(tm_date);
 }
@@ -623,7 +675,7 @@ char *orage_icaltime_to_i18_time(const char *icaltime)
     return(ct);
 }
 
-char *orage_icaltime_to_i18_time_short(const char *icaltime)
+char *orage_icaltime_to_i18_time_only(const char *icaltime)
 {
     struct tm t;
     static char i18_time[10];
@@ -749,47 +801,122 @@ void orage_select_today(GtkCalendar *cal)
  * data and config file locations
  *******************************************************/
 
+gboolean orage_copy_file(gchar *source, gchar *target)
+{
+    gchar *text;
+    gsize text_len;
+    GError *error = NULL;
+    gboolean ok = TRUE;
+
+    /* read file */
+    if (!g_file_get_contents(source, &text, &text_len, &error)) {
+        orage_message(150, "orage_copy_file: Could not open file (%s) error:%s"
+                , source, error->message);
+        g_error_free(error);
+        ok = FALSE;
+    }
+    /* write file */
+    if (!g_file_set_contents(target, text, -1, &error)) {
+        orage_message(150, "orage_copy_file: Could not write file (%s) error:%s"
+                , target, error->message);
+        g_error_free(error);
+        ok = FALSE;
+    }
+    g_free(text);
+    return(ok);
+}
+
+gchar *orage_xdg_system_data_file_location(char *name)
+{
+    char *file_name;
+    const gchar * const *base_dirs;
+    int i;
+
+    base_dirs = g_get_system_data_dirs();
+    for (i = 0; base_dirs[i] != NULL; i++) {
+        file_name = g_build_filename(base_dirs[i], name, NULL);
+        if (g_file_test(file_name, G_FILE_TEST_IS_REGULAR)) {
+            return(file_name);
+        }
+        g_free(file_name);
+    }
+
+    /* no system wide data file */
+    return(NULL);
+}
+
+/* Returns valid xdg local data file name. 
+   If the file did not exist, it checks if there are system defaults 
+   and creates it from those */
 gchar *orage_data_file_location(char *name)
 {
-    char *file_name, *dir_name;
+    char *file_name, *dir_name, *sys_name;
     const char *base_dir;
     int mode = 0700;
 
-    /*
-    file_name = xfce_resource_save_location(XFCE_RESOURCE_DATA, name, TRUE);
-    g_print("orage_data_file_location (%s) (%s)\n", file_name, g_get_user_data_dir());
-    */
-
     base_dir = g_get_user_data_dir();
     file_name = g_build_filename(base_dir, name, NULL);
-    dir_name = g_path_get_dirname((const gchar *)file_name);
-    if (g_mkdir_with_parents(dir_name, mode)) {
-        g_print("orage_data_file_location: (%s) (%s) directory creation failed.\n", base_dir, file_name);
+    if (!g_file_test(file_name, G_FILE_TEST_IS_REGULAR)) {
+        /* it does not exist, let's try to create it */
+        dir_name = g_path_get_dirname((const gchar *)file_name);
+        if (g_mkdir_with_parents(dir_name, mode)) {
+            orage_message(150, "orage_data_file_location: (%s) (%s) directory creation failed.\n", base_dir, file_name);
+        }
+        g_free(dir_name);
+        /* now we have the directories ready, let's check for system default */
+        sys_name = orage_xdg_system_data_file_location(name);
+        if (sys_name) { /* we found it, we need to copy it */
+            orage_copy_file(sys_name, file_name);
+        }
     }
-    g_free(dir_name);
 
     return(file_name);
 }
 
+/* these are default files and must only be read */
+gchar *orage_xdg_system_config_file_location(char *name)
+{
+    char *file_name;
+    const gchar * const *base_dirs;
+    int i;
+
+    base_dirs = g_get_system_config_dirs();
+    for (i = 0; base_dirs[i] != NULL; i++) {
+        file_name = g_build_filename(base_dirs[i], name, NULL);
+        if (g_file_test(file_name, G_FILE_TEST_IS_REGULAR)) {
+            return(file_name);
+        }
+        g_free(file_name);
+    }
+
+    /* no system wide config file */
+    return(NULL);
+}
+
+/* Returns valid xdg local config file name. 
+   If the file did not exist, it checks if there are system defaults 
+   and creates it from those */
 gchar *orage_config_file_location(char *name)
 {
-    char *file_name, *dir_name;
+    char *file_name, *dir_name, *sys_name;
     const char *base_dir;
     int mode = 0700;
 
-    /*
-    file_name = xfce_resource_save_location(XFCE_RESOURCE_CONFIG, name
-            , TRUE);
-    g_print("orage_config_file_location (%s) (%s)\n", file_name, g_get_user_config_dir());
-    */
-
     base_dir = g_get_user_config_dir();
     file_name = g_build_filename(base_dir, name, NULL);
-    dir_name = g_path_get_dirname((const gchar *)file_name);
-    if (g_mkdir_with_parents(dir_name, mode)) {
-        g_print("orage_config_file_location: (%s) (%s) directory creation failed.\n", base_dir, file_name);
+    if (!g_file_test(file_name, G_FILE_TEST_IS_REGULAR)) {
+        /* it does not exist, let's try to create it */
+        dir_name = g_path_get_dirname((const gchar *)file_name);
+        if (g_mkdir_with_parents(dir_name, mode)) {
+            orage_message(150, "orage_config_file_location: (%s) (%s) directory creation failed.\n", base_dir, file_name);
+        }
+        g_free(dir_name);
+        /* now we have the directories ready, let's check for system default */
+        sys_name = orage_xdg_system_config_file_location(name);
+        if (sys_name) { /* we found it, we need to copy it */
+            orage_copy_file(sys_name, file_name);
+        }
     }
-    g_free(dir_name);
 
     return(file_name);
 }
@@ -815,7 +942,9 @@ OrageRc *orage_rc_file_open(char *fpath, gboolean read_only)
         orc->cur_group = NULL;
     }
     else {
+#ifdef ORAGE_DEBUG
         orage_message(-90, "orage_rc_file_open: Unable to open RC file (%s). Creating it. (%s)", fpath, error->message);
+#endif
         g_clear_error(&error);
         if (g_file_set_contents((const gchar *)fpath, "#Created by Orage", -1
                     , &error)) { /* successfully created new file */
@@ -826,7 +955,9 @@ OrageRc *orage_rc_file_open(char *fpath, gboolean read_only)
             orc->cur_group = NULL;
         }
         else {
+#ifdef ORAGE_DEBUG
             orage_message(150, "orage_rc_file_open: Unable to open (create) RC file (%s). (%s)", fpath, error->message);
+#endif
             g_key_file_free(grc);
         }
     }
@@ -859,7 +990,9 @@ void orage_rc_file_close(OrageRc *orc)
         g_free(orc);
     }
     else {
+#ifdef ORAGE_DEBUG
         orage_message(-90, "orage_rc_file_close: closing empty file.");
+#endif
     }
 }
 
@@ -880,7 +1013,9 @@ void orage_rc_del_group(OrageRc *orc, char *grp)
 
     if (!g_key_file_remove_group((GKeyFile *)orc->rc, (const gchar *)grp
                 , &error)) {
+#ifdef ORAGE_DEBUG
         orage_message(150, "orage_rc_del_group: Group remove failed. RC file (%s). group (%s) (%s)", orc->file_name, grp, error->message);
+#endif
     }
 }
 
@@ -898,7 +1033,9 @@ gchar *orage_rc_get_str(OrageRc *orc, char *key, char *def)
             , (const gchar *)key, &error);
     if (!ret && error) {
         ret = g_strdup(def);
+#ifdef ORAGE_DEBUG
         orage_message(-90, "orage_rc_get_str: str (%s) group (%s) in RC file (%s) not found, using default (%s)", key, orc->cur_group, orc->file_name, ret);
+#endif
     }
     return(ret);
 }
@@ -912,7 +1049,9 @@ gint orage_rc_get_int(OrageRc *orc, char *key, gint def)
             , (const gchar *)key, &error);
     if (!ret && error) {
         ret = def;
+#ifdef ORAGE_DEBUG
         orage_message(-90, "orage_rc_get_int: str (%s) group (%s) in RC file (%s) not found, using default (%d)", key, orc->cur_group, orc->file_name, ret);
+#endif
     }
     return(ret);
 }
@@ -926,7 +1065,9 @@ gboolean orage_rc_get_bool(OrageRc *orc, char *key, gboolean def)
             , (const gchar *)key, &error);
     if (!ret && error) {
         ret = def;
+#ifdef ORAGE_DEBUG
         orage_message(-90, "orage_rc_get_bool: str (%s) group (%s) in RC file (%s) not found, using default (%d)", key, orc->cur_group, orc->file_name, ret);
+#endif
     }
     return(ret);
 }
